MODULE sms_pisces   
   !!----------------------------------------------------------------------
   !!                     ***  sms_pisces.F90  ***  
   !! TOP :   PISCES Source Minus Sink variables
   !!----------------------------------------------------------------------
   !! History :   1.0  !  2000-02 (O. Aumont) original code
   !!             3.2  !  2009-04 (C. Ethe & NEMO team) style
   !!----------------------------------------------------------------------

#if defined key_pisces
   !!----------------------------------------------------------------------
   !!   'key_pisces'                                         PISCES model
   !!----------------------------------------------------------------------
   USE par_oce
   USE par_trc

   IMPLICIT NONE
   PUBLIC

   !!*  Time variables
   INTEGER  ::   nrdttrc           !: ???
   INTEGER  ::   ndayflxtr         !: ???
   REAL(wp) ::   rfact , rfactr    !: ???
   REAL(wp) ::   rfact2, rfact2r   !: ???

   !!*  Biological parameters 
   REAL(wp) ::   part              !: ???
   REAL(wp) ::   rno3              !: ???
   REAL(wp) ::   o2ut              !: ???
   REAL(wp) ::   po4r              !: ???
   REAL(wp) ::   rdenit            !: ???
   REAL(wp) ::   o2nit             !: ???
   REAL(wp) ::   wsbio, wsbio2     !: ???
   REAL(wp) ::   xkmort            !: ???
   REAL(wp) ::   ferat3            !: ???

   !!* Damping 
   LOGICAL  ::   ln_pisdmp         !: relaxation or not of nutrients to a mean value
                                   !: when initialize from a restart file 
   LOGICAL  ::   ln_pisclo         !: Restoring or not of nutrients to initial value
                                   !: on close seas

   !!*  Biological fluxes for light
   INTEGER , DIMENSION(jpi,jpj)     ::   neln       !: number of T-levels + 1 in the euphotic layer
   REAL(wp), DIMENSION(jpi,jpj)     ::   heup       !: euphotic layer depth

   !!*  Biological fluxes for primary production
   REAL(wp), DIMENSION(jpi,jpj)     ::   xksi       !: ???
   REAL(wp), DIMENSION(jpi,jpj)     ::   xksimax    !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   xnanono3   !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   xdiatno3   !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   xnanonh4   !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   xdiatnh4   !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   xlimphy    !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   xlimdia    !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   concdfe    !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   concnfe    !: ???

   !!*  SMS for the organic matter
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   xfracal    !: ??
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   nitrfac    !: ??
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   xlimbac    !: ??
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   xdiss      !: ??
#if defined key_trc_dia3d
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   prodcal    !: Calcite production
#endif

   !!* Variable for chemistry of the CO2 cycle
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   akb3       !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   ak13       !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   ak23       !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   aksp       !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   akw3       !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   borat      !: ???
   REAL(wp), DIMENSION(jpi,jpj,jpk) ::   hi         !: ???

#if defined key_kriest
   !!*  Kriest parameter for aggregation
   REAL(wp) ::   xkr_eta                            !: ???
   REAL(wp) ::   xkr_zeta                           !: ???
   REAL(wp) ::   xkr_massp                          !: ???
   REAL(wp) ::   xkr_mass_min, xkr_mass_max         !: ???
#endif

#else
   !!----------------------------------------------------------------------   
   !!  Empty module :                                     NO PISCES model
   !!----------------------------------------------------------------------
#endif
   
   !!----------------------------------------------------------------------
   !! NEMO/TOP 3.2 , LOCEAN-IPSL (2009) 
   !! $Id$ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!======================================================================   
END MODULE sms_pisces    
